security: documentation: clarify return values for getKey and getCerticicate.
diff --git a/ndn-cpp/security/identity/memory-identity-storage.hpp b/ndn-cpp/security/identity/memory-identity-storage.hpp
index 980f78d..ba0ea5a 100644
--- a/ndn-cpp/security/identity/memory-identity-storage.hpp
+++ b/ndn-cpp/security/identity/memory-identity-storage.hpp
@@ -84,6 +84,7 @@
   /**
    * Get the public key DER blob from the identity storage.
    * @param keyName The name of the requested public key.
+   * @return The DER Blob.  If not found, return a Blob with a null pointer.
    */
   virtual Blob
   getKey(const Name& keyName);
@@ -121,7 +122,7 @@
    * Get a certificate from the identity storage.
    * @param certificateName The name of the requested certificate.
    * @param allowAny If false, only a valid certificate will be returned, otherwise validity is disregarded.
-   * @return The requested certificate.
+   * @return The requested certificate.  If not found, return a shared_ptr with a null pointer.
    */
   virtual ptr_lib::shared_ptr<Certificate> 
   getCertificate(const Name &certificateName, bool allowAny = false);
@@ -165,10 +166,10 @@
   /**
    * Set the default key name for the specified identity.
    * @param keyName The key name.
    * @param identityName (optional) The identity name to check the keyName.
    */
   virtual void 
-  setDefaultKeyNameForIdentity(const Name& keyName, const Name& identityName = Name());
+  setDefaultKeyNameForIdentity(const Name& keyName, const Name& identityNameCheck = Name());
 
   /**
    * Set the default key name for the specified identity.
@@ -165,10 +166,10 @@
    * Set the default key name for the specified identity.
    * @param keyName The key name.
-   * @param identityName (optional) The identity name to check the keyName.
+   * @param identityNameCheck (optional) The identity name to check the keyName.
    */
   virtual void 